@@ -1,19 +1,18 @@
-package Extism::XS;
-
+package Extism::XS v0.3.0;
 use 5.016;
 use strict;
 use warnings;
 use Exporter 'import';
 
-use version 0.77;
-our $VERSION = qv(v0.2.0);
-
 require XSLoader;
+our $VERSION;
 XSLoader::load('Extism::XS', $VERSION);
 
 our @EXPORT_OK = qw(
     version
     plugin_new
+    plugin_new_with_fuel_limit
+    plugin_allow_http_response_headers
     plugin_new_error_free
     plugin_call
     plugin_error
@@ -33,9 +32,13 @@ our @EXPORT_OK = qw(
     current_plugin_memory_alloc
     current_plugin_memory_length
     current_plugin_memory_free
+    current_plugin_host_context
     log_file
     log_custom
     log_drain
+    compiled_plugin_new
+    compiled_plugin_free
+    plugin_new_from_compiled
     CopyToPtr
 );
 
